@@ -15,7 +15,7 @@ The code below shows a typical use of `MivotViewer
         print(f"space frame is  {mivot_instance.Coordinate_coordSys.spaceRefFrame.value}")
 
         mivot_object = mivot_viewer.dm_instance
-        while mivot_viewer.next():
+        while mivot_viewer.next_row_view():
             print(f"latitude={mivot_object.latitude.value}")
             print(f"longitude={mivot_object.longitude.value}")
 
@@ -56,7 +56,7 @@ class MivotViewer:
     MivotViewer is a PyVO table wrapper aiming at providing
     a model view on VOTable data read with usual tools.
     """
-    def __init__(self, votable_path, tableref=None):
+    def __init__(self, votable_path, tableref=None, resolve_ref=False):
         """
         Constructor of the MivotViewer class.
 
@@ -68,6 +68,13 @@ class MivotViewer:
         tableref : str, optional
             Used to identify the table to process. If not specified,
             the first table is taken by default.
+        Parameters
+        ----------
+        resolve_ref : bool, optional
+            If True, replace the REFERENCE elements with a copy of the objects they refer to.
+            e.g. copy the space coordinates system, usually located in the GLOBALS
+            block, in the position objects
+            Default is False.
         """
         if not check_astropy_version():
             raise AstropyVersionException(f"Astropy version {version.version} "
@@ -93,6 +100,7 @@ class MivotViewer:
         self._mapped_tables = []
         self._resource_seeker = None
         self._dm_instance = None
+        self._resolve_ref = resolve_ref
         try:
             self._set_resource()
             self._set_mapping_block()
@@ -188,7 +196,7 @@ class MivotViewer:
         """ getter for the current astropy.table.array row """
         return self._current_data_row
 
-    def next(self):
+    def next_row_view(self):
         """
         jump to the next table row and update the MivotInstance instance
 
@@ -371,18 +379,13 @@ class MivotViewer:
         self._set_column_indices()
         self._set_column_units()
 
-    def _get_model_view(self, resolve_ref=True):
+    def _get_model_view(self):
         """
         Return an XML model view of the last read row.
         This function resolves references by default.
-
-        Parameters
-        ----------
-        resolve_ref : bool, optional
-            If True, resolves the references. Default is True.
         """
         templates_copy = deepcopy(self._templates)
-        if resolve_ref is True:
+        if self._resolve_ref is True:
             while StaticReferenceResolver.resolve(self._annotation_seeker, self._connected_tableref,
                                                   templates_copy) > 0:
                 pass
